@@ -39,7 +39,7 @@ use Image::ExifTool qw(GetByteOrder SetByteOrder Get32u Get32s Set32u
                        Get16u Get16s Set16u);
 use vars qw($VERSION);
 
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 sub AddFixup($$;$$);
 sub ApplyFixup($$);
@@ -69,7 +69,7 @@ sub new
 sub Clone($)
 {
     my $self = shift;
-    my $clone = new Image::ExifTool::Fixup;
+    my $clone = Image::ExifTool::Fixup->new;
     $clone->{Start} = $self->{Start};
     $clone->{Shift} = $self->{Shift};
     my $phash = $self->{Pointers};
@@ -317,7 +317,7 @@ Image::ExifTool::Fixup - Utility to handle pointer fixups
 
     use Image::ExifTool::Fixup;
 
-    $fixup = new Image::ExifTool::Fixup;
+    $fixup = Image::ExifTool::Fixup->new;
 
     # add a new fixup to a pointer at the specified offset in data
     $fixup->AddFixup($offset);
@@ -354,7 +354,7 @@ linear list when ApplyFixups() is called.
 
 =head1 AUTHOR
 
-Copyright 2003-2019, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
